from setuptools import find_packages, setup
setup(
    name='deez69420',
    packages=find_packages(),
    version='0.1.1',
    description='funny:)',
    author='Lawrence LOng',
    license='MIT',
)

